spec2nexus
==========

Converts SPEC data files and scans into NeXus HDF5 files:

    $ spec2nexus  path/to/file/specfile.dat

Writes `path/to/file/specfile.hdf5`

- Conda install:  `conda install -c prjemian spec2nexus` (alternate)
- Conda install:  `conda install -c aps-anl-tag spec2nexus` (production)
- Conda install:  `conda install -c aps-anl-dev spec2nexus` (development)
- Pip install:  `pip install spec2nexus`

**NOTE**

spec2nexus will stop development for Python 2 by 2019-12-31. 
For more information, visit https://python3statement.org/.

Provides
--------

-   **spec2nexus** : command-line tool: Convert
    [SPEC](http://certif.com) data files to
    [NeXus](http://nexusformat.org) [HDF5](http://hdfgroup.org)
-   **extractSpecScan** : command-line tool: Save columns from SPEC data
    file scan(s) to TSV files
-   **spec** : library: python binding to read SPEC data files
-   **eznx** : library: (Easy NeXus) supports writing NeXus HDF5 files
    using h5py
-   **specplot** : command-line tool: plot a SPEC scan to an image file
-   **specplot\_gallery** : command-line tool: call **specplot** for all
    scans in a list of files, makes a web gallery

Package Information
-------------------

-   **author**: Pete R. Jemian
-   **email**: <prjemian@gmail.com>
-   **copyright**: 2014-2019, Pete R. Jemian
-   **license**: Creative Commons Attribution 4.0 International Public
    License (see
    [LICENSE.txt](http://spec2nexus.readthedocs.io/en/latest/license.html)
    file)
-   **URL**: documentation: <http://spec2nexus.readthedocs.io>
-   **git**: source: <https://github.com/prjemian/spec2nexus>
-   **PyPI**: Distribution: <https://pypi.python.org/pypi/spec2nexus/>
-   **OpenHub**: Compare open source software:
    <https://www.openhub.net/p/spec2nexus>
-   **Release Notes**:
    <https://github.com/prjemian/spec2nexus/wiki/Release-Notes>


-   **citation**:
    [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3246491.svg)](https://doi.org/10.5281/zenodo.3246491)
    <!-- [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.595735.svg)](https://doi.org/10.5281/zenodo.595735) -->

-   **build badges**:
    [![image](https://travis-ci.org/prjemian/spec2nexus.svg?branch=master)](https://travis-ci.org/prjemian/spec2nexus)
    [![image](https://coveralls.io/repos/github/prjemian/spec2nexus/badge.svg?branch=master)](https://coveralls.io/github/prjemian/spec2nexus?branch=master)
    [![Total alerts](https://img.shields.io/lgtm/alerts/g/prjemian/spec2nexus.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/prjemian/spec2nexus/alerts/)

-   **release badges**:
    [![image](https://img.shields.io/pypi/pyversions/spec2nexus.svg)](https://pypi.python.org/pypi/spec2nexus)
    [![image](https://img.shields.io/github/tag/prjemian/spec2nexus.svg)](https://github.com/prjemian/spec2nexus/tags)
    [![image](https://img.shields.io/github/release/prjemian/spec2nexus.svg)](https://github.com/prjemian/spec2nexus/releases)
    [![image](https://img.shields.io/pypi/v/spec2nexus.svg)](https://pypi.python.org/pypi/spec2nexus/)
    [![image](https://anaconda.org/prjemian/spec2nexus/badges/version.svg)](https://anaconda.org/prjemian/spec2nexus)

-   **community badges**
    [![image](http://depsy.org/api/package/pypi/spec2nexus/badge.svg)](http://depsy.org/package/python/spec2nexus)
    [![Join the chat at https://gitter.im/spec2nexus/Lobby](https://badges.gitter.im/spec2nexus/Lobby.svg)](https://gitter.im/spec2nexus/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
